@@ -8,7 +8,7 @@ use strict;
 use vars qw($VERSION);
 use Carp;
 
-$VERSION = "1.00";
+$VERSION = "1.03";
 
 my %secflags = (
 	noplaintext  => 1,
@@ -27,9 +27,9 @@ sub client_new {
     host     => $host     || '',
   };
 
-  # Dumb selection;
-
-  my @mpkg = grep {
+  my @mpkg = sort {
+    $b->_order <=> $a->_order
+  } grep {
     eval "require $_;" && $_->_secflags(@sec) == @sec
   } map {
     (my $mpkg = __PACKAGE__ . "::$_") =~ s/-/_/g;
@@ -40,12 +40,18 @@ sub client_new {
   $mpkg[0]->_init($self);
 }
 
-sub code  { 0  }
-sub error { '' }
-
+sub _order { 0 }
+sub code     { defined(shift->{error}) || 0 }
+sub error    { shift->{error}    }
 sub service  { shift->{service}  }
 sub host     { shift->{host}     }
 
+sub set_error {
+  my $self = shift;
+  $self->{error} = shift;
+  return;
+}
+
 # set/get property
 sub property {
   my $self = shift;
@@ -100,6 +106,8 @@ sub _call {
 
 sub _secflags { 0 }
 
+sub securesocket { $_[1] }
+
 1;
 
 
